/***************************************************************************
 $RCSfile: transferview.h,v $
                             -------------------
    cvs         : $Id: transferview.h,v 1.10 2005/09/07 15:38:38 aquamaniac Exp $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/



#ifndef KBANKING_TRANSFERVIEW_H
#define KBANKING_TRANSFERVIEW_H

#include "transferview.ui.h"

#include <qwidget.h>

#include <aqbanking/job.h>

class TransferView;
class KBanking;


#include "transferlist.h"


class TransferView: public TransferViewUi {
  Q_OBJECT
public:
  TransferView(KBanking *app,
               QWidget* parent=0, const char* name=0, WFlags fl=0);
  ~TransferView();

  bool init();
  bool fini();

protected:
  //void resizeEvent(QResizeEvent *e);
  void closeEvent(QCloseEvent *e);

private:
  KBanking *_app;
  TransferListView *_xaList;

public slots:
  void slotUpdated();
  void slotDetails();
  void slotNewTransfer();
  void slotNewDebitNote();
  void slotNewEuTransfer();
  void slotRepeat();

};










#endif /* KBANKING_TRANSFERVIEW_H */



